==> jei-1.21.10-fabric-26.1.1.17-sources.jar: mezz/jei/gui/elements/GuiIconButton.java <==
package mezz.jei.gui.elements;

import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.handlers.IGuiProperties;
import mezz.jei.common.input.IInternalKeyMappings;
import mezz.jei.common.util.ImmutableRect2i;
import mezz.jei.gui.input.IUserInputHandler;
import mezz.jei.gui.input.UserInput;
import net.minecraft.class_10799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_768;
import net.minecraft.class_8666;
import net.minecraft.class_9848;
import java.util.Optional;

/**
 * A gui button that has an {@link IDrawable} instead of a string label.
 */
public class GuiIconButton extends class_4185 {
	// TODO re-implement the "clicked" state when something is held down
	private static final class_8666 SPRITES = new class_8666(
		class_2960.method_60656("widget/button"),
		class_2960.method_60656("widget/button_disabled"),
		class_2960.method_60656("widget/button_highlighted")
	);

	private IDrawable icon;
	private boolean pressed = false;
	private boolean forcePressed = false;

	public GuiIconButton(int x, int y, int width, int height, IDrawable icon, class_4241 pressable) {
		super(x, y, width, height, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public GuiIconButton(IDrawable icon, class_4241 pressable) {
		super(0, 0, 0, 0, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public void updateBounds(class_768 area) {
		method_46421(area.method_3321());
		method_46419(area.method_3322());
		this.field_22758 = area.method_3319();
		this.field_22759 = area.method_3320();
	}

	public void updateBounds(ImmutableRect2i area) {
		method_46421(area.getX());
		method_46419(area.getY());
		this.field_22758 = area.getWidth();
		this.field_22759 = area.getHeight();
	}

	@Override
	public void method_53533(int value) {
		this.field_22759 = value;
	}

	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTicks) {
		class_2960 spriteLocation = SPRITES.method_52729(this.field_22763, this.method_25367());
		guiGraphics.method_52707(class_10799.field_56883, spriteLocation, this.method_46426(), this.method_46427(), this.method_25368(), this.method_25364(), class_9848.method_61317(this.field_22765));

		float xOffset = method_46426() + (field_22758 - icon.getWidth()) / 2.0f;
		float yOffset = method_46427() + (field_22759 - icon.getHeight()) / 2.0f;
		if (this.pressed || this.forcePressed) {
			xOffset += 0.5f;
			yOffset += 0.5f;
		}
		var poseStack = guiGraphics.method_51448();
		poseStack.pushMatrix();
		{
			poseStack.translate(xOffset, yOffset);
			icon.draw(guiGraphics);
		}
		poseStack.popMatrix();
	}

	public IUserInputHandler createInputHandler() {
		return new UserInputHandler(this);
	}

	public void setForcePressed(boolean forcePressed) {
		this.forcePressed = forcePressed;
	}

	public ImmutableRect2i getArea() {
		return new ImmutableRect2i(method_46426(), method_46427(), field_22758, field_22759);
	}

	public void setIcon(IDrawable icon) {
		this.icon = icon;
	}

	private class UserInputHandler implements IUserInputHandler {
		private final GuiIconButton button;

		public UserInputHandler(GuiIconButton button) {
			this.button = button;
		}

		@Override
		public Optional<IUserInputHandler> handleUserInput(class_437 screen, IGuiProperties guiProperties, UserInput input, IInternalKeyMappings keyBindings) {
			this.button.pressed = false;

			boolean handled = input.ifMouseEvent((event, doubleClicked) -> {
				double mouseX = event.comp_4798();
				double mouseY = event.comp_4799();
				if (!this.button.field_22763 || !this.button.field_22764 || !method_25405(mouseX, mouseY)) {
					return false;
				}
				if (!this.button.method_25351(event.comp_4800())) {
					return false;
				}
				if (!input.isSimulate()) {
					this.button.method_25354(class_310.method_1551().method_1483());
					this.button.method_25348(event, doubleClicked);
				} else {
					this.button.pressed = true;
				}
				return true;
			});

			if (handled) {
				return Optional.of(this);
			}
			return Optional.empty();
		}

		@Override
		public void unfocus() {
			this.button.pressed = false;
		}
	}
}

==> jei-1.21.11-fabric-27.0.0.1-sources.jar: mezz/jei/gui/elements/GuiIconButton.java <==
package mezz.jei.gui.elements;

import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.handlers.IGuiProperties;
import mezz.jei.common.input.IInternalKeyMappings;
import mezz.jei.common.util.ImmutableRect2i;
import mezz.jei.gui.input.IUserInputHandler;
import mezz.jei.gui.input.UserInput;
import net.minecraft.class_10799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_768;
import net.minecraft.class_8666;
import net.minecraft.class_9848;
import java.util.Optional;

/**
 * A gui button that has an {@link IDrawable} instead of a string label.
 */
public class GuiIconButton extends class_4185 {
	// TODO re-implement the "clicked" state when something is held down
	private static final class_8666 SPRITES = new class_8666(
		class_2960.method_60656("widget/button"),
		class_2960.method_60656("widget/button_disabled"),
		class_2960.method_60656("widget/button_highlighted")
	);

	private IDrawable icon;
	private boolean pressed = false;
	private boolean forcePressed = false;

	public GuiIconButton(int x, int y, int width, int height, IDrawable icon, class_4241 pressable) {
		super(x, y, width, height, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public GuiIconButton(IDrawable icon, class_4241 pressable) {
		super(0, 0, 0, 0, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public void updateBounds(class_768 area) {
		method_46421(area.method_3321());
		method_46419(area.method_3322());
		this.field_22758 = area.method_3319();
		this.field_22759 = area.method_3320();
	}

	public void updateBounds(ImmutableRect2i area) {
		method_46421(area.getX());
		method_46419(area.getY());
		this.field_22758 = area.getWidth();
		this.field_22759 = area.getHeight();
	}

	@Override
	public void method_53533(int value) {
		this.field_22759 = value;
	}

	@Override
	protected void method_75752(class_332 guiGraphics, int mouseX, int mouseY, float partialTicks) {
		class_2960 spriteLocation = SPRITES.method_52729(this.field_22763, this.method_25367());
		guiGraphics.method_52707(class_10799.field_56883, spriteLocation, this.method_46426(), this.method_46427(), this.method_25368(), this.method_25364(), class_9848.method_61317(this.field_22765));

		float xOffset = method_46426() + (field_22758 - icon.getWidth()) / 2.0f;
		float yOffset = method_46427() + (field_22759 - icon.getHeight()) / 2.0f;
		if (this.pressed || this.forcePressed) {
			xOffset += 0.5f;
			yOffset += 0.5f;
		}
		var poseStack = guiGraphics.method_51448();
		poseStack.pushMatrix();
		{
			poseStack.translate(xOffset, yOffset);
			icon.draw(guiGraphics);
		}
		poseStack.popMatrix();
	}

	public IUserInputHandler createInputHandler() {
		return new UserInputHandler(this);
	}

	public void setForcePressed(boolean forcePressed) {
		this.forcePressed = forcePressed;
	}

	public ImmutableRect2i getArea() {
		return new ImmutableRect2i(method_46426(), method_46427(), field_22758, field_22759);
	}

	public void setIcon(IDrawable icon) {
		this.icon = icon;
	}

	private class UserInputHandler implements IUserInputHandler {
		private final GuiIconButton button;

		public UserInputHandler(GuiIconButton button) {
			this.button = button;
		}

		@Override
		public Optional<IUserInputHandler> handleUserInput(class_437 screen, IGuiProperties guiProperties, UserInput input, IInternalKeyMappings keyBindings) {
			this.button.pressed = false;

			boolean handled = input.ifMouseEvent((event, doubleClicked) -> {
				double mouseX = event.comp_4798();
				double mouseY = event.comp_4799();
				if (!this.button.field_22763 || !this.button.field_22764 || !method_25405(mouseX, mouseY)) {
					return false;
				}
				if (!this.button.method_25351(event.comp_4800())) {
					return false;
				}
				if (!input.isSimulate()) {
					this.button.method_25354(class_310.method_1551().method_1483());
					this.button.method_25348(event, doubleClicked);
				} else {
					this.button.pressed = true;
				}
				return true;
			});

			if (handled) {
				return Optional.of(this);
			}
			return Optional.empty();
		}

		@Override
		public void unfocus() {
			this.button.pressed = false;
		}
	}
}
